@@ -3,7 +3,7 @@
 #' \code{eigensort} performs the spectral decomposition of a symmetric matrix. The eigenvalues and eigenvectors are sorted in increasing order by eigenvalues.
 #'
 #' @export eigensort
-#' @param x Symmetric matrix, either sparse or dense, to be decomposed.
+#' @param M Symmetric matrix, either sparse or dense, to be decomposed.
 #'
 #' @return A list containing:
 #' \itemize{
@@ -15,8 +15,8 @@
 #' A <- matrix(1, ncol=2, nrow=2)
 #' dec <- eigensort(A)
 
-eigensort <- function(x) {
-  dec <- eigen(x, symmetric = T)
+eigensort <- function(M) {
+  dec <- eigen(M, symmetric = T)
   A <- dec$vectors
   return(list(evalues = rev(dec$values),
               evectors = A[, ncol(A):1]))
